Python API
==========

Spicerack Python API autodoc.

.. automodule:: spicerack
   :members:

.. autodata:: __version__

.. rubric:: Subpackages and Submodules

.. toctree::

   spicerack.actions
   spicerack.administrative
   spicerack.confctl
   spicerack.config
   spicerack.constants
   spicerack.debmonitor
   spicerack.decorators
   spicerack.dns
   spicerack.dnsdisc
   spicerack.elasticsearch_cluster
   spicerack.exceptions
   spicerack.ganeti
   spicerack.icinga
   spicerack.interactive
   spicerack.ipmi
   spicerack.management
   spicerack.mediawiki
   spicerack.mysql
   spicerack.mysql_legacy
   spicerack.netbox
   spicerack.phabricator
   spicerack.prometheus
   spicerack.puppet
   spicerack.redis_cluster
   spicerack.remote
   spicerack.typing

.. The spicerack.cookbook and spicerack.log module are explicitely excluded from the public documentation as they
   should not be used directly by the cookbooks.
